DROP TABLE IF EXISTS tb_file;
CREATE TABLE tb_file (
  id          INTEGER,
  path        TEXT,
  size        INTEGER,
  isDir       INTEGER,
  lastModify  INTEGER,
  lastUpdated INTEGER,
  PRIMARY KEY (id)
    ON CONFLICT REPLACE,
  UNIQUE (path)
    ON CONFLICT REPLACE
);

DROP TABLE IF EXISTS tb_cache_file;
CREATE TABLE tb_cache_file (
  tag      TEXT,
  lastUsed INTEGER,
  UNIQUE (tag)
    ON CONFLICT REPLACE
);

DROP TABLE IF EXISTS tb_garbage_cache;
CREATE TABLE tb_garbage_cache (
  id          INTEGER,
  lastUpdated INTEGER,
  tag         TEXT,
  PRIMARY KEY (id)
    ON CONFLICT REPLACE,
  UNIQUE (tag)
    ON CONFLICT REPLACE
);

DROP TABLE IF EXISTS tb_garbage_bean;
CREATE TABLE tb_garbage_bean (
  id                 INTEGER,
  contentType        INTEGER,
  latestModification INTEGER,
  deleted            INTEGER,
  pathType           INTEGER,
  regPkgName         TEXT,
  subPath            TEXT,
  subPathLevel       INTEGER,
  flag               INTEGER,
  appName            TEXT,
  title              TEXT,
  desc               TEXT,
  alertInfo          TEXT,
  simpleAlertInfo    TEXT,
  rootPathEncrypted  TEXT,
  pathEncrypted      TEXT,
  pkgNameEncrypted   TEXT,
  lastUpdated        INTEGER,
  PRIMARY KEY (id)
    ON CONFLICT REPLACE
);

DROP TABLE IF EXISTS tb_garbage_content_type;
CREATE TABLE tb_garbage_content_type (
  id          INTEGER,
  adviceLevel INTEGER,
  labelId     INTEGER,
  orderType   INTEGER,
  rank        INTEGER,
  title       TEXT,
  desc        TEXT,
  alertInfo   TEXT,
  PRIMARY KEY (id)
    ON CONFLICT REPLACE
);

DROP TABLE IF EXISTS tb_garbage_label;
CREATE TABLE tb_garbage_label (
  id        INTEGER,
  name      TEXT,
  rank      INTEGER,
  orderType INTEGER,
  PRIMARY KEY (id)
    ON CONFLICT REPLACE
);

DROP TABLE IF EXISTS tb_white_list;
CREATE TABLE tb_white_list (
  id       INTEGER,
  filePath TEXT,
  type     INTEGER,
  PRIMARY KEY (id)
    ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS tb_ignored_garbage (
  contentType INTEGER NOT NULL,
  packageName TEXT    NOT NULL,
  path        TEXT    NOT NULL,
  UNIQUE (contentType, packageName, path)
    ON CONFLICT REPLACE
);

DROP TABLE IF EXISTS tb_mem_clean_time;
CREATE TABLE tb_mem_clean_time (
  packageName TEXT    NOT NULL,
  time        INTEGER NOT NULL,
  UNIQUE (packageName)
    ON CONFLICT REPLACE
);

INSERT INTO tb_garbage_label (id, name, rank, orderType) VALUES (1, '安装包', 1, 3);
INSERT INTO tb_garbage_label (id, name, rank, orderType) VALUES (2, '本地文件', 2, 3);
INSERT INTO tb_garbage_label (id, name, rank, orderType) VALUES (3, '视频', 3, 3);
INSERT INTO tb_garbage_label (id, name, rank, orderType) VALUES (4, '应用中的文件', 4, 1);
INSERT INTO tb_garbage_label (id, name, rank, orderType) VALUES (5, '电子书', 5, 3);
INSERT INTO tb_garbage_label (id, name, rank, orderType) VALUES (6, '音乐', 6, 1);
INSERT INTO tb_garbage_label (id, name, rank, orderType) VALUES (7, '游戏', 7, 1);
INSERT INTO tb_garbage_label (id, name, rank, orderType) VALUES (8, '建议清理', 0, 1);

INSERT INTO tb_garbage_content_type (id, adviceLevel, labelId, orderType, rank, title, "desc", alertInfo) VALUES (1, 0, 8, 1, 0, '系统垃圾文件', '', '无用的系统运行记录，不影响使用，建议清理');
INSERT INTO tb_garbage_content_type (id, adviceLevel, labelId, orderType, rank, title, "desc", alertInfo) VALUES (3, 0, 1, 1, 3, '装过的安装包', ' ', '使用过的应用安装包，不影响使用，可以清理');
INSERT INTO tb_garbage_content_type (id, adviceLevel, labelId, orderType, rank, title, "desc", alertInfo) VALUES (5, 1, 1, 1, 2, '新安装包', '', '还没使用过的应用安装包');
INSERT INTO tb_garbage_content_type (id, adviceLevel, labelId, orderType, rank, title, "desc", alertInfo) VALUES (6, 1, 2, 1, 2, '大文件', '', '手机上大于 10M 的文件');
INSERT INTO tb_garbage_content_type (id, adviceLevel, labelId, orderType, rank, title, "desc", alertInfo) VALUES (87, 0, 8, 1, 0, '可清理加速内存', '', '后台无用的内存占用，清理可提高手机速度');
